/*
============================================================================
 Name        : EGLHelper.h
 Author      : Konstantin Tretyakov
 Version     :
 Copyright   : Copyright 2006, Konstantin Tretyakov
 Description : EGLHelper class declaration
============================================================================
*/
#ifndef EGLHELPER_H_
#define EGLHELPER_H_

#include <GLES/egl.h>
#include <w32std.h>
#include <e32std.h>
#include <gdi.h>
#include <fbs.h>

// Convenience class:
//   Helps to initialize, store, and destroy EGL state.
//
class EGLHelper {
public:
        // The display where the graphics are drawn
        EGLDisplay  display;
        
        // The rendering context
        EGLContext  context;
        
        // The window where the graphics are drawn
        EGLSurface  surface;
        
        EGLConfig   config;
        
        // Empty constructor
        EGLHelper(){};
                
        // Initializes display, surface and context and makes the context current
        void initEGL(RWindow& window, CFbsBitmap* bitmap);
        
        // Deinitializes EGL.
        void destroyEGL();
        
        // Init viewport
        void initViewport(GLint width, GLint height);
        
        // Swap buffers
        void swapBuffers();

private:
        // Initializes display for the correct display mode
        void initDisplay(TDisplayMode displayMode);
};


#endif /*EGLHELPER_H_*/
