/*
============================================================================
 Name        : GameControl.h
 Author      : Konstantin Tretyakov
 Version     :
 Copyright   : Copyright 2006, Konstantin Tretyakov
 Description : CGameControl declaration
============================================================================
*/

#ifndef GameControl_H
#define GameControl_H

#include <e32std.h>
#include <e32base.h>
#include "EGLHelper.h"
#include "EGLTextureHelper.h"
#include "GameWorld.h"
#include "SyMazeSoundAdapter.h"

enum TGameStatus {
    // Messages go first, it's important    
    ETitle1Msg = 0, ETitle2Msg, ETitle3Msg, EBonusMapMsg, EBonusPortalMsg,
    EBonusWeaponMsg, EFinishMsg,
    EFirstPersonView, EMapView
};


/**
 *  CGameControl
 * 
 */
class CGameControl : public CBase
{
public: // Constructors and destructor
	~CGameControl();
    
    // Two-phased constructors.
	static CGameControl* NewL(EGLHelper* aEglHelper);
    static CGameControl* NewLC(EGLHelper* aEglHelper);
private:
    int frame;
    EGLHelper* iEglHelper; // We don't free this one
    CEGLTextureHelper* iTextureHelper; // .. and neither this one
    CGameState* iGameState;
    CSyMazeSoundAdapter* iSoundAdapter;
    
	// 1st stage construction
	CGameControl();
	// 2nd stage construction
	void ConstructL();

public: // Logic
    TGameStatus iGameStatus;

    void InitL(CEGLTextureHelper* textureHelper);
    
    void Cycle();
    
    void Quit();
    
    // positive is 1 or -1
    void Turn(int positive);
    
    // forward/left/up are 1/0/-1
    void Move(int forward, int left, int up);
    
    // Toggle Map View
    void MapToggle();
    
    // Shooting
    void Shoot();
    
    // OK Button
    void OKButton();
    
    // Callbacks invoked by CGameState when events happen
    void ReachedLevel1();
    void ReachedLevel2();
    void ReachedFinish();
    void FoundWeapon();
};

#endif // GameControl_H
