/*
============================================================================
 Name        : GameRendererStaticData.h
 Author      : Konstantin Tretyakov
 Version     :
 Copyright   : Copyright 2006, Konstantin Tretyakov
 Description : Static data used in game renderer (cube vertices, edges, texture coords)
============================================================================
*/
#ifndef GAMERENDERERSTATICDATA_H_
#define GAMERENDERERSTATICDATA_H_

static const GLbyte cubevertices[8 * 3] = {
     -1,  1,  1,
      1,  1,  1,
      1, -1,  1,
     -1, -1,  1,

     -1,  1, -1,
      1,  1, -1,
      1, -1, -1,
     -1, -1, -1
};

static const GLfloat cubenormals[8 * 3] = {
      0,  0,  1,
      1,  0,  0,
      0,  0,  -1,
     -1,  0,  0,

      0,  1,  0,
      0,  -1, 0,
};



static const GLubyte cubetriangles[12 * 3] = {
    /* front */
    1,0,3,
    1,3,2,

    /* right */
    2,6,5,
    2,5,1,
    
    /* back */
    7,4,5,
    7,5,6,
    
    /* left */
    0,4,7,
    0,7,3,
    
    /* top */
    5,4,0,
    5,0,1,
    
    /* bottom */
    3,7,6,
    3,6,2
};

static const GLfloat floorTexCoords[] = {
    0,0,
    0,1,
    1,1,
    1,0,
    0,0,
    0,1,
    1,1,
    1,0
};

static const GLfloat cubeTexCoords[] = {
    0,0,
    0.33,0,
    0.66,0,
    0.99,0,
    0,0.33,
    0.33,0.33,
    0.66,0.33,
    0.99,0.33
};


static const GLubyte vertexcolors[8 * 4] = {
    0  ,255,  0,255,
    0  ,  0,255,255,
    0  ,255,  0,255,
    255,  0,  0,255,

    0  ,  0,255,255,
    255,  0,  0,255,
    0  ,  0,255,255,
    0  ,255,  0,255
    };

static const GLfloat mazeColors[] = {
    1, 1, 1, 1, // Default white
    1, 1, 1, 1, 
    1, 0, 0, 1, // Red
    0, 1, 0, 1, // Green
    0, 0, 1, 1,  // Blue
    0.9, 0.9, 0.9, 1, // Gradations of gray (NB! indices 5..8 hardcoded in TBullets::Behave!)
    0.7, 0.7, 0.7, 1,
    0.5, 0.5, 0.5, 1,
    0.3, 0.3, 0.3, 1
};

static const GLubyte cubefan1[6 * 3] = {
    1,0,3,
    1,3,2,
    1,2,6,
    1,6,5,
    1,5,4,
    1,4,0
};

static const GLubyte cubefan2[6 * 3] = {
    7,4,5,
    7,5,6,
    7,6,2,
    7,2,3,
    7,3,0,
    7,0,4
};


// Lighting
static const GLfloat globalAmbient[4]   = { 0.1, 0.1, 0.1, 1.0 };
static const GLfloat lightDiffuseLamp[4]   = { 1.0, 1.0, 1.0, 1.0 };
static const GLfloat lightAmbientLamp[4]   = { 0.2, 0.2, 0.2, 1.0 };
static const GLfloat lightPositionLamp[4]  = { 0, -1, 0, 1.0 };


// Bullets / boids
static const GLfloat bulletVertices[8 * 3] = {
     -0.5, -0.5, -0.5,
      0.5, -0.5, -0.5,
      0.0, -0.5,  0.5,
      0.0,  1.0,  0.0 };

static const GLubyte bulletTriangles[12 * 3] = {
    0, 1, 2,
    1, 3, 2,
    2, 3, 0,
    1, 0, 3
};


#endif /*GAMERENDERERSTATICDATA_H_*/
