/*
============================================================================
 Name        : EGLHelper.cpp
 Author      : Konstantin Tretyakov
 Version     :
 Copyright   : Copyright 2006, Konstantin Tretyakov
 Description : CEGLHelper implementation
============================================================================
*/
#include "EGLHelper.h"

// The current implementation doesn't really help a lot...
inline void Oops(char* /*msg*/) { // Should be a buffer class instead of char*
    _LIT(KMessage, "Panic!"); // Aaaa! I don't know how to output msg!
    User::Panic( KMessage, 0 );
}



void EGLHelper::initEGL(RWindow& window, CFbsBitmap* bitmap) {
    initDisplay(window.DisplayMode());
    
    context = eglCreateContext(display, config, NULL, NULL);
    if (context == NULL) Oops("eglCreateContext failed");
    
    surface = eglCreateWindowSurface(display, config, &window, NULL);    
    //surface = eglCreatePixmapSurface(display, config, bitmap, NULL);    
    if (surface == NULL) Oops("eglCreateSurface failed");

    if (eglMakeCurrent(display, surface, surface, context) == EGL_FALSE )
        Oops("eglMakeCurrent failed");
}


void EGLHelper::destroyEGL() {
    // Release resources associated with EGL
    eglMakeCurrent(display, EGL_NO_SURFACE, EGL_NO_SURFACE, EGL_NO_CONTEXT);
    eglDestroyContext(display, context);    
    eglDestroySurface(display, surface); 
    eglTerminate(display);    
}

        
void EGLHelper::initDisplay(TDisplayMode displayMode) {
    
    // Get the display for drawing graphics
    display = eglGetDisplay(EGL_DEFAULT_DISPLAY);
    if (display == NULL) Oops("eglGetDisplay failed");

    // Initialize display
    if (eglInitialize(display, NULL, NULL) == EGL_FALSE)
        Oops("eglInitialize failed");

    EGLConfig *configList = NULL; // Pointer for EGLConfigs
    EGLint numOfConfigs = 0; 
    EGLint configSize   = 0;

    // Get the number of possible EGLConfigs
    if (eglGetConfigs(display, configList, configSize, &numOfConfigs) == EGL_FALSE)
        Oops("eglGetConfigs failed");

    configSize = numOfConfigs;

    // Allocate memory for the configList 
    configList = (EGLConfig*) User::Alloc(sizeof(EGLConfig)*configSize);
    if (configList == NULL) Oops("config alloc failed");

    /* Define properties for the wanted EGLSurface.
       To get the best possible performance, choose
       an EGLConfig with a buffersize matching
       the current window's display mode*/

    TInt BufferSize;

    switch (displayMode) {
        case(EColor4K):
             BufferSize = 12;
             break;
         case(EColor64K):
             BufferSize = 16;
             break;
         case(EColor16M):
             BufferSize = 24;
             break;
         case(EColor16MU):
             BufferSize = 18;
             break;
         default:
             Oops("unsupported displaymode");
             break;
    }

    // Define properties for the wanted EGLSurface 
    const EGLint attrib_list[] = { EGL_BUFFER_SIZE, BufferSize, 
                                   EGL_DEPTH_SIZE, 16,
                                   EGL_SURFACE_TYPE, EGL_WINDOW_BIT, // EGL_PIXMAP_BIT
                                   EGL_NONE };

    // Choose an EGLConfig that best matches to the properties in attrib_list 
    if (eglChooseConfig(display, attrib_list, configList, configSize, &numOfConfigs) == EGL_FALSE)
        Oops("eglChooseConfig failed");

    config = configList[0];   // Choose the best EGLConfig. EGLConfigs 
                              // returned by eglChooseConfig are sorted so 
                              // that the best matching EGLConfig is first in
                              // the list.
    User::Free(configList);   // Free configList, not used anymore.
}


void EGLHelper::initViewport(GLint width, GLint height) {
    glClearColor(0, 0, 0, 0);   
    glViewport(0, 0, width, height);
}


void EGLHelper::swapBuffers() {
    eglSwapBuffers(display, surface);
}

