/*
============================================================================
 Name        : EGLTextureHelper.cpp
 Author      : Konstantin Tretyakov
 Version     :
 Copyright   : Copyright 2006, Konstantin Tretyakov
 Description : CEGLTextureHelper implementation
============================================================================
*/

#include "EGLTextureHelper.h"
#include <eikenv.h>

CEGLTextureHelper::CEGLTextureHelper()
{
	// No implementation required
}


CEGLTextureHelper::~CEGLTextureHelper()
{
    iCustomTextureGc->DiscardFont();
    delete iCustomTextureGc;
    delete iCustomTextureDevice;
    bitmaps.ResetAndDestroy();
}

CEGLTextureHelper* CEGLTextureHelper::NewLC()
{
	CEGLTextureHelper* self = new (ELeave)CEGLTextureHelper();
	CleanupStack::PushL(self);
	self->ConstructL();
	return self;
}

CEGLTextureHelper* CEGLTextureHelper::NewL()
{
	CEGLTextureHelper* self=CEGLTextureHelper::NewLC();
	CleanupStack::Pop(); // self;
	return self;
}

void CEGLTextureHelper::ConstructL()
{
}


void CEGLTextureHelper::LoadImagesL() {
    
    _LIT(KDataFilename, "data.mbm");
    TFileName fullName(KDataFilename);
    CompleteWithAppPath(fullName);
        
     // Initalize images
    for (int i = 0; i < TEXTURE_COUNT; i++) {
        CFbsBitmap* tex = new (ELeave) CFbsBitmap;
        CleanupStack::PushL(tex);
        if (!bitmaps.Append(tex)) CleanupStack::Pop();
        else {
            //TODO: Raise an exception or something..
        }
        
        // Load texture bitmap
        if (TEXTURE_ORDER[i] >= 0) {
            tex->Load(fullName, TEXTURE_ORDER[i]);
        
            // TODO: This might crash if tex wasn't loaded
            // Switch BGR -> RGB
            TUint8 *texPtr = (TUint8*)tex->DataAddress();
            TUint8 t;
            for(TInt i = 0; i < TEX_WIDTH*TEX_HEIGHT; i++)
            {
                t = texPtr[i*3];
                texPtr[i*3] = texPtr[i*3+2];
                texPtr[i*3+2] = t;
            }
        }
        else { // Just create an empty image
            tex->Create(TSize(256,256), EColor16M);
        }
    }
    
    // Create device & context for the custom bitmap
    iCustomTextureDevice = CFbsBitmapDevice::NewL(bitmaps[ETextureCustom]);
    User::LeaveIfError(iCustomTextureDevice->CreateBitmapContext(iCustomTextureGc));
}


void CEGLTextureHelper::GlGenTextures() {
    glGenTextures(TEXTURE_COUNT, glTextures);
    for (int i = 0; i < TEXTURE_COUNT; i++) {
        glBindTexture(GL_TEXTURE_2D, glTextures[i]);
        glTexImage2D(GL_TEXTURE_2D, 0, GL_RGB, TEX_WIDTH, TEX_HEIGHT, 0, GL_RGB, GL_UNSIGNED_BYTE, bitmaps[i]->DataAddress());
    }
}

void CEGLTextureHelper::GlDeleteTextures() {
    glDeleteTextures(TEXTURE_COUNT, glTextures);
}

void CEGLTextureHelper::GlSetTexture(TTextureName texture) {
    glEnable(GL_TEXTURE_2D);
    glBindTexture(GL_TEXTURE_2D, glTextures[texture]);
}


void CEGLTextureHelper::GlSetNoTexture() {
    glDisable(GL_TEXTURE_2D);
}


void CEGLTextureHelper::GlReloadCustomTexture() {
        glBindTexture(GL_TEXTURE_2D, glTextures[ETextureCustom]);
        glTexImage2D(GL_TEXTURE_2D, 0, GL_RGB, TEX_WIDTH, TEX_HEIGHT, 0, GL_RGB, GL_UNSIGNED_BYTE, bitmaps[ETextureCustom]->DataAddress());
}

