/*
============================================================================
 Name        : SyMazeContainer.cpp
 Author      : Konstantin Tretyakov
 Version     :
 Copyright   : Copyright 2006, Konstantin Tretyakov
 Description : Container control implementation
============================================================================
*/

// INCLUDE FILES
#include "SyMazeContainer.h"


// ================= MEMBER FUNCTIONS =======================

// ---------------------------------------------------------
// CSyMazeContainer::ConstructL(const TRect& aRect)
// EPOC two phased constructor
// ---------------------------------------------------------
//

void CSyMazeContainer::ConstructL(const TRect& /*aRect*/)
{
    CreateWindowL();
    ActivateL();
    SetExtentToWholeScreen();
    
    iOffscreenBitmap = new (ELeave) CFbsBitmap;
    iOffscreenBitmap->Create(Rect().Size(), Window().DisplayMode());

    iEglHelper.initEGL(Window(), iOffscreenBitmap);
    iEglHelper.initViewport(Rect().Width(), Rect().Height());

    iTextureHelper = CEGLTextureHelper::NewL();
    iTextureHelper->LoadImagesL();

    // Create timer and game control
    iTimer = CPeriodic::NewL(CActive::EPriorityIdle);
    iGameControl = CGameControl::NewL(&iEglHelper);
    iGameControl->InitL(iTextureHelper);
    iTimer->Start(10000, 10000, TCallBack(CSyMazeContainer::TimerCallback, iGameControl));
}

// Destructor
CSyMazeContainer::~CSyMazeContainer()
{
    delete iTimer;
    if (iGameControl != NULL) iGameControl->Quit();
    delete iGameControl;    
    iEglHelper.destroyEGL();
    delete iTextureHelper;
    delete iOffscreenBitmap;
}

// Timer callback
TInt CSyMazeContainer::TimerCallback(TAny* aInstance) {
    CGameControl* instance = (CGameControl*) aInstance;
    instance->Cycle();
    return 0; 
}


